
.. image:: https://www.pandapower.org/images/pp.svg
   :target: https://www.pandapower.org
   :alt: logo

|

.. image:: https://badge.fury.io/py/pandapower.svg
   :target: https://pypi.python.org/pypi/pandapower
   :alt: PyPI

.. image:: https://img.shields.io/pypi/pyversions/pandapower.svg
   :target: https://pypi.python.org/pypi/pandapower
   :alt: versions

.. image:: https://readthedocs.org/projects/pandapower/badge/
   :target: http://pandapower.readthedocs.io/
   :alt: docs

.. image:: https://codecov.io/github/e2nIEE/pandapower/coverage.svg?branch=master
   :target: https://app.codecov.io/github/e2nIEE/pandapower?branch=master
   :alt: codecov

.. image:: https://api.codacy.com/project/badge/Grade/e2ce960935fd4f96b4be4dff9a0c76e3
   :target: https://app.codacy.com/gh/e2nIEE/pandapower?branch=master
   :alt: codacy

.. image:: https://img.shields.io/badge/License-BSD%203--Clause-blue.svg
   :target: https://github.com/e2nIEE/pandapower/blob/master/LICENSE
   :alt: BSD

.. image:: https://pepy.tech/badge/pandapower
   :target: https://pepy.tech/project/pandapower
   :alt: pepy

.. image:: https://mybinder.org/badge_logo.svg
   :target: https://mybinder.org/v2/gh/e2nIEE/pandapower/master?filepath=tutorials
   :alt: binder





pandapower is an easy to use network calculation program aimed to automate the analysis and optimization of power
systems. It uses the data analysis library `pandas <http://pandas.pydata.org>`_ and is compatible with the commonly
used MATPOWER / PYPOWER case format. pandapower allows using different solvers including an improved Newton-Raphson
power flow implementation, all `PYPOWER <https://pypi.python.org/pypi/PYPOWER>`_ solvers, the C++ library solvers for fast steady-state distribution power system analysis of `PowerGridModel <https://github.com/PowerGridModel/power-grid-model>`_, the Newton-Raphson power flow solvers in the C++ library `lightsim2grid <https://github.com/BDonnot/lightsim2grid/>`_, and the
`PowerModels.jl <https://github.com/lanl-ansi/PowerModels.jl/>`_ library.

More information about pandapower can be found on `www.pandapower.org <https://www.pandapower.org/>`_:

About pandapower:

- `Power System Modeling <https://www.pandapower.org/about/#modeling>`_
- `Power System Analysis <https://www.pandapower.org/about/#analysis>`_
- `Citing pandapower <https://www.pandapower.org/references/>`_

Getting Started:

- `Installation Notes <https://www.pandapower.org/start/>`_
- `Minimal Example <https://www.pandapower.org/start/#intro>`_
- `Interactive Tutorials <https://www.pandapower.org/start/#tutorials>`_
- `Documentation <https://pandapower.readthedocs.io/>`_

If you are interested in the latest pandapower developments, subscribe to our `mailing list <https://www.pandapower.org/contact/#list>`_!

.. image:: https://simbench.de/wp-content/uploads/2019/01/logo.png
   :target: https://www.simbench.net
   :alt: SimBench_logo

To get realistic load profile data and grid models across all voltage levels that are ready to
be used in pandapower, have a look at the *SimBench* `project website <https://www.simbench.net>`_ or
`on GitHub <https://github.com/e2nIEE/simbench>`_.

.. image:: https://www.pandapipes.org/images/pp.svg
   :target: https://www.pandapipes.org
   :width: 270pt
   :alt: pandapipes_logo

If you want to model pipe networks (heat, gas or water) as well, we recommend
pandapower's sibling project *pandapipes* (`website <https://www.pandapipes.org>`_, `GitHub repository <https://github.com/e2nIEE/pandapipes>`_).

|

pandapower is a joint development of the research group of the Department for Sustainable Electrical Energy Systems (e2n), University of Kassel and the Department for Distribution System
Operation at the Fraunhofer Institute for Energy Economics and Energy System Technology (IEE), Kassel.

.. image:: http://www.pandapower.org/images/contact/Logo_e2n.png
    :target: https://www.uni-kassel.de/eecs/en/sections/energiemanagement-und-betrieb-elektrischer-netze/home
    :width: 500

|

.. image:: https://www.pandapower.org/images/contact/Logo_Fraunhofer_IEE.png
    :target: https://www.iee.fraunhofer.de/en.html
    :width: 500

|

We welcome contributions to pandapower of any kind - if you want to contribute, please check out the `pandapower contribution guidelines <https://github.com/e2nIEE/pandapower/blob/develop/CONTRIBUTING.rst>`_.
